# coding: utf-8

# flake8: noqa
"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from pulpcore.client.pulp_ansible.models.ansible_ansible_collection_deprecated import AnsibleAnsibleCollectionDeprecated
from pulpcore.client.pulp_ansible.models.ansible_ansible_collection_deprecated_response import AnsibleAnsibleCollectionDeprecatedResponse
from pulpcore.client.pulp_ansible.models.ansible_ansible_distribution import AnsibleAnsibleDistribution
from pulpcore.client.pulp_ansible.models.ansible_ansible_distribution_response import AnsibleAnsibleDistributionResponse
from pulpcore.client.pulp_ansible.models.ansible_ansible_namespace_metadata import AnsibleAnsibleNamespaceMetadata
from pulpcore.client.pulp_ansible.models.ansible_ansible_namespace_metadata_response import AnsibleAnsibleNamespaceMetadataResponse
from pulpcore.client.pulp_ansible.models.ansible_ansible_repository import AnsibleAnsibleRepository
from pulpcore.client.pulp_ansible.models.ansible_ansible_repository_response import AnsibleAnsibleRepositoryResponse
from pulpcore.client.pulp_ansible.models.ansible_collection_remote import AnsibleCollectionRemote
from pulpcore.client.pulp_ansible.models.ansible_collection_remote_response import AnsibleCollectionRemoteResponse
from pulpcore.client.pulp_ansible.models.ansible_collection_remote_response_hidden_fields_inner import AnsibleCollectionRemoteResponseHiddenFieldsInner
from pulpcore.client.pulp_ansible.models.ansible_collection_response import AnsibleCollectionResponse
from pulpcore.client.pulp_ansible.models.ansible_collection_version_mark import AnsibleCollectionVersionMark
from pulpcore.client.pulp_ansible.models.ansible_collection_version_mark_response import AnsibleCollectionVersionMarkResponse
from pulpcore.client.pulp_ansible.models.ansible_collection_version_response import AnsibleCollectionVersionResponse
from pulpcore.client.pulp_ansible.models.ansible_collection_version_signature_response import AnsibleCollectionVersionSignatureResponse
from pulpcore.client.pulp_ansible.models.ansible_git_remote import AnsibleGitRemote
from pulpcore.client.pulp_ansible.models.ansible_git_remote_response import AnsibleGitRemoteResponse
from pulpcore.client.pulp_ansible.models.ansible_repository_mark import AnsibleRepositoryMark
from pulpcore.client.pulp_ansible.models.ansible_repository_rebuild import AnsibleRepositoryRebuild
from pulpcore.client.pulp_ansible.models.ansible_repository_signature import AnsibleRepositorySignature
from pulpcore.client.pulp_ansible.models.ansible_repository_sync_url import AnsibleRepositorySyncURL
from pulpcore.client.pulp_ansible.models.ansible_role import AnsibleRole
from pulpcore.client.pulp_ansible.models.ansible_role_remote import AnsibleRoleRemote
from pulpcore.client.pulp_ansible.models.ansible_role_remote_response import AnsibleRoleRemoteResponse
from pulpcore.client.pulp_ansible.models.ansible_role_response import AnsibleRoleResponse
from pulpcore.client.pulp_ansible.models.ansible_tag_response import AnsibleTagResponse
from pulpcore.client.pulp_ansible.models.artifact_ref_response import ArtifactRefResponse
from pulpcore.client.pulp_ansible.models.async_operation_response import AsyncOperationResponse
from pulpcore.client.pulp_ansible.models.client_configuration_response import ClientConfigurationResponse
from pulpcore.client.pulp_ansible.models.collection_import_detail_response import CollectionImportDetailResponse
from pulpcore.client.pulp_ansible.models.collection_metadata_response import CollectionMetadataResponse
from pulpcore.client.pulp_ansible.models.collection_namespace_response import CollectionNamespaceResponse
from pulpcore.client.pulp_ansible.models.collection_ref_response import CollectionRefResponse
from pulpcore.client.pulp_ansible.models.collection_response import CollectionResponse
from pulpcore.client.pulp_ansible.models.collection_summary_response import CollectionSummaryResponse
from pulpcore.client.pulp_ansible.models.collection_version_copy_move import CollectionVersionCopyMove
from pulpcore.client.pulp_ansible.models.collection_version_docs_response import CollectionVersionDocsResponse
from pulpcore.client.pulp_ansible.models.collection_version_list_response import CollectionVersionListResponse
from pulpcore.client.pulp_ansible.models.collection_version_response import CollectionVersionResponse
from pulpcore.client.pulp_ansible.models.collection_version_search_list import CollectionVersionSearchList
from pulpcore.client.pulp_ansible.models.collection_version_search_list_response import CollectionVersionSearchListResponse
from pulpcore.client.pulp_ansible.models.collection_version_signature_response import CollectionVersionSignatureResponse
from pulpcore.client.pulp_ansible.models.content_summary_response import ContentSummaryResponse
from pulpcore.client.pulp_ansible.models.copy import Copy
from pulpcore.client.pulp_ansible.models.galaxy_role_response import GalaxyRoleResponse
from pulpcore.client.pulp_ansible.models.galaxy_role_version_response import GalaxyRoleVersionResponse
from pulpcore.client.pulp_ansible.models.my_permissions_response import MyPermissionsResponse
from pulpcore.client.pulp_ansible.models.namespace_link import NamespaceLink
from pulpcore.client.pulp_ansible.models.namespace_link_response import NamespaceLinkResponse
from pulpcore.client.pulp_ansible.models.nested_role import NestedRole
from pulpcore.client.pulp_ansible.models.nested_role_response import NestedRoleResponse
from pulpcore.client.pulp_ansible.models.object_roles_response import ObjectRolesResponse
from pulpcore.client.pulp_ansible.models.paginated_collection_response_list import PaginatedCollectionResponseList
from pulpcore.client.pulp_ansible.models.paginated_collection_response_list_links import PaginatedCollectionResponseListLinks
from pulpcore.client.pulp_ansible.models.paginated_collection_response_list_meta import PaginatedCollectionResponseListMeta
from pulpcore.client.pulp_ansible.models.paginated_collection_version_list_response_list import PaginatedCollectionVersionListResponseList
from pulpcore.client.pulp_ansible.models.paginated_collection_version_search_list_response_list import PaginatedCollectionVersionSearchListResponseList
from pulpcore.client.pulp_ansible.models.paginated_galaxy_role_response_list import PaginatedGalaxyRoleResponseList
from pulpcore.client.pulp_ansible.models.paginated_galaxy_role_version_response_list import PaginatedGalaxyRoleVersionResponseList
from pulpcore.client.pulp_ansible.models.paginated_repository_version_response_list import PaginatedRepositoryVersionResponseList
from pulpcore.client.pulp_ansible.models.paginated_tag_response_list import PaginatedTagResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_ansible_collection_deprecated_response_list import PaginatedansibleAnsibleCollectionDeprecatedResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_ansible_distribution_response_list import PaginatedansibleAnsibleDistributionResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_ansible_namespace_metadata_response_list import PaginatedansibleAnsibleNamespaceMetadataResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_ansible_repository_response_list import PaginatedansibleAnsibleRepositoryResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_collection_remote_response_list import PaginatedansibleCollectionRemoteResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_collection_response_list import PaginatedansibleCollectionResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_collection_version_mark_response_list import PaginatedansibleCollectionVersionMarkResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_collection_version_response_list import PaginatedansibleCollectionVersionResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_collection_version_signature_response_list import PaginatedansibleCollectionVersionSignatureResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_git_remote_response_list import PaginatedansibleGitRemoteResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_role_remote_response_list import PaginatedansibleRoleRemoteResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_role_response_list import PaginatedansibleRoleResponseList
from pulpcore.client.pulp_ansible.models.patched_collection import PatchedCollection
from pulpcore.client.pulp_ansible.models.patchedansible_ansible_distribution import PatchedansibleAnsibleDistribution
from pulpcore.client.pulp_ansible.models.patchedansible_ansible_repository import PatchedansibleAnsibleRepository
from pulpcore.client.pulp_ansible.models.patchedansible_collection_remote import PatchedansibleCollectionRemote
from pulpcore.client.pulp_ansible.models.patchedansible_git_remote import PatchedansibleGitRemote
from pulpcore.client.pulp_ansible.models.patchedansible_role_remote import PatchedansibleRoleRemote
from pulpcore.client.pulp_ansible.models.policy_enum import PolicyEnum
from pulpcore.client.pulp_ansible.models.repair import Repair
from pulpcore.client.pulp_ansible.models.repo_metadata_response import RepoMetadataResponse
from pulpcore.client.pulp_ansible.models.repository import Repository
from pulpcore.client.pulp_ansible.models.repository_add_remove_content import RepositoryAddRemoveContent
from pulpcore.client.pulp_ansible.models.repository_response import RepositoryResponse
from pulpcore.client.pulp_ansible.models.repository_version_response import RepositoryVersionResponse
from pulpcore.client.pulp_ansible.models.set_label import SetLabel
from pulpcore.client.pulp_ansible.models.set_label_response import SetLabelResponse
from pulpcore.client.pulp_ansible.models.tag_response import TagResponse
from pulpcore.client.pulp_ansible.models.unpaginated_collection_version_response import UnpaginatedCollectionVersionResponse
from pulpcore.client.pulp_ansible.models.unset_label import UnsetLabel
from pulpcore.client.pulp_ansible.models.unset_label_response import UnsetLabelResponse



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_ansible.models.paginatedansible_collection_version_response_list import PaginatedansibleCollectionVersionResponseList

class TestPaginatedansibleCollectionVersionResponseList(unittest.TestCase):
    """PaginatedansibleCollectionVersionResponseList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedansibleCollectionVersionResponseList:
        """Test PaginatedansibleCollectionVersionResponseList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedansibleCollectionVersionResponseList`
        """
        model = PaginatedansibleCollectionVersionResponseList()
        if include_optional:
            return PaginatedansibleCollectionVersionResponseList(
                count = 123,
                next = 'http://api.example.org/accounts/?offset=400&limit=100',
                previous = 'http://api.example.org/accounts/?offset=200&limit=100',
                results = [
                    pulpcore.client.pulp_ansible.models.ansible/collection_version_response.ansible.CollectionVersionResponse(
                        prn = '', 
                        pulp_labels = {
                            'key' : ''
                            }, 
                        artifact = '', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        pulp_href = '', 
                        sha256 = '', 
                        md5 = '', 
                        sha1 = '', 
                        sha224 = '', 
                        sha384 = '', 
                        sha512 = '', 
                        id = '', 
                        authors = [
                            ''
                            ], 
                        dependencies = pulpcore.client.pulp_ansible.models.dependencies.dependencies(), 
                        description = '', 
                        documentation = '', 
                        homepage = '', 
                        issues = '', 
                        license = [
                            ''
                            ], 
                        name = '', 
                        namespace = '', 
                        origin_repository = '', 
                        tags = [
                            pulpcore.client.pulp_ansible.models.ansible/tag_response.ansible.TagResponse(
                                name = '', )
                            ], 
                        version = '', 
                        requires_ansible = '', )
                    ]
            )
        else:
            return PaginatedansibleCollectionVersionResponseList(
                count = 123,
                results = [
                    pulpcore.client.pulp_ansible.models.ansible/collection_version_response.ansible.CollectionVersionResponse(
                        prn = '', 
                        pulp_labels = {
                            'key' : ''
                            }, 
                        artifact = '', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        pulp_href = '', 
                        sha256 = '', 
                        md5 = '', 
                        sha1 = '', 
                        sha224 = '', 
                        sha384 = '', 
                        sha512 = '', 
                        id = '', 
                        authors = [
                            ''
                            ], 
                        dependencies = pulpcore.client.pulp_ansible.models.dependencies.dependencies(), 
                        description = '', 
                        documentation = '', 
                        homepage = '', 
                        issues = '', 
                        license = [
                            ''
                            ], 
                        name = '', 
                        namespace = '', 
                        origin_repository = '', 
                        tags = [
                            pulpcore.client.pulp_ansible.models.ansible/tag_response.ansible.TagResponse(
                                name = '', )
                            ], 
                        version = '', 
                        requires_ansible = '', )
                    ],
        )
        """

    def testPaginatedansibleCollectionVersionResponseList(self):
        """Test PaginatedansibleCollectionVersionResponseList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_ansible.models.ansible_collection_remote_response import AnsibleCollectionRemoteResponse

class TestAnsibleCollectionRemoteResponse(unittest.TestCase):
    """AnsibleCollectionRemoteResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AnsibleCollectionRemoteResponse:
        """Test AnsibleCollectionRemoteResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AnsibleCollectionRemoteResponse`
        """
        model = AnsibleCollectionRemoteResponse()
        if include_optional:
            return AnsibleCollectionRemoteResponse(
                pulp_href = '',
                prn = '',
                pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                name = '',
                url = '',
                ca_cert = '',
                client_cert = '',
                tls_validation = True,
                proxy_url = '',
                pulp_labels = {
                    'key' : ''
                    },
                download_concurrency = 1,
                max_retries = 56,
                policy = 'immediate',
                total_timeout = 0.0,
                connect_timeout = 0.0,
                sock_connect_timeout = 0.0,
                sock_read_timeout = 0.0,
                headers = [
                    None
                    ],
                rate_limit = 56,
                hidden_fields = [
                    pulpcore.client.pulp_ansible.models.ansible_collection_remote_response_hidden_fields_inner.ansible_CollectionRemoteResponse_hidden_fields_inner(
                        name = '', 
                        is_set = True, )
                    ],
                requirements_file = '',
                auth_url = '',
                sync_dependencies = True,
                signed_only = True,
                last_sync_task = ''
            )
        else:
            return AnsibleCollectionRemoteResponse(
                name = '',
                url = '',
        )
        """

    def testAnsibleCollectionRemoteResponse(self):
        """Test AnsibleCollectionRemoteResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_ansible.models.ansible_collection_version_response import AnsibleCollectionVersionResponse

class TestAnsibleCollectionVersionResponse(unittest.TestCase):
    """AnsibleCollectionVersionResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AnsibleCollectionVersionResponse:
        """Test AnsibleCollectionVersionResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AnsibleCollectionVersionResponse`
        """
        model = AnsibleCollectionVersionResponse()
        if include_optional:
            return AnsibleCollectionVersionResponse(
                prn = '',
                pulp_labels = {
                    'key' : ''
                    },
                artifact = '',
                pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                pulp_href = '',
                sha256 = '',
                md5 = '',
                sha1 = '',
                sha224 = '',
                sha384 = '',
                sha512 = '',
                id = '',
                authors = [
                    ''
                    ],
                dependencies = pulpcore.client.pulp_ansible.models.dependencies.dependencies(),
                description = '',
                documentation = '',
                homepage = '',
                issues = '',
                license = [
                    ''
                    ],
                name = '',
                namespace = '',
                origin_repository = '',
                tags = [
                    pulpcore.client.pulp_ansible.models.ansible/tag_response.ansible.TagResponse(
                        name = '', )
                    ],
                version = '',
                requires_ansible = ''
            )
        else:
            return AnsibleCollectionVersionResponse(
        )
        """

    def testAnsibleCollectionVersionResponse(self):
        """Test AnsibleCollectionVersionResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_ansible.api.pulp_ansible_artifacts_collections_v3_api import PulpAnsibleArtifactsCollectionsV3Api


class TestPulpAnsibleArtifactsCollectionsV3Api(unittest.TestCase):
    """PulpAnsibleArtifactsCollectionsV3Api unit test stubs"""

    def setUp(self) -> None:
        self.api = PulpAnsibleArtifactsCollectionsV3Api()

    def tearDown(self) -> None:
        pass

    def test_create(self) -> None:
        """Test case for create

        Upload a collection
        """
        pass

    def test_create_0(self) -> None:
        """Test case for create_0

        Upload a collection
        """
        pass

    def test_create_1(self) -> None:
        """Test case for create_1

        Upload a collection
        """
        pass

    def test_create_2(self) -> None:
        """Test case for create_2

        Upload a collection
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self


class OneOf:
    @staticmethod
    def from_dict(obj, *args, **kwargs):
        """Noop override to fix missing OneOf import/implementation."""
        return obj


class CollectionResponse(BaseModel):
    """
    A serializer for a Collection.
    """ # noqa: E501
    href: Optional[StrictStr] = Field(default=None, description="Get href.")
    namespace: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    deprecated: StrictBool
    versions_url: Optional[StrictStr] = Field(default=None, description="Get a link to a collection versions list.")
    highest_version: Optional[Dict[str, Any]] = Field(default=None, description="Get a highest version and its link.")
    created_at: Optional[datetime] = Field(default=None, description="Get the timestamp of the lowest version CollectionVersion's created timestamp.")
    updated_at: Optional[datetime] = Field(default=None, description="Get the timestamp of the latest version CollectionVersion's created timestamp.")
    download_count: Optional[StrictInt] = Field(default=None, description="Get the download count of the collection")
    __properties: ClassVar[List[str]] = ["href", "namespace", "name", "deprecated", "versions_url", "highest_version", "created_at", "updated_at", "download_count"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CollectionResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "href",
            "namespace",
            "name",
            "versions_url",
            "highest_version",
            "created_at",
            "updated_at",
            "download_count",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CollectionResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "href": obj.get("href"),
            "namespace": obj.get("namespace"),
            "name": obj.get("name"),
            "deprecated": obj.get("deprecated"),
            "versions_url": obj.get("versions_url"),
            "highest_version": obj.get("highest_version"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "download_count": obj.get("download_count")
        })
        return _obj





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_ansible.models.unpaginated_collection_version_response import UnpaginatedCollectionVersionResponse

class TestUnpaginatedCollectionVersionResponse(unittest.TestCase):
    """UnpaginatedCollectionVersionResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UnpaginatedCollectionVersionResponse:
        """Test UnpaginatedCollectionVersionResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UnpaginatedCollectionVersionResponse`
        """
        model = UnpaginatedCollectionVersionResponse()
        if include_optional:
            return UnpaginatedCollectionVersionResponse(
                version = '',
                href = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                requires_ansible = '',
                marks = [
                    ''
                    ],
                artifact = pulpcore.client.pulp_ansible.models.artifact_ref_response.ArtifactRefResponse(
                    filename = '', 
                    sha256 = '', 
                    size = 56, ),
                collection = pulpcore.client.pulp_ansible.models.collection_ref_response.CollectionRefResponse(
                    id = '', 
                    name = '', 
                    href = '', ),
                download_url = '',
                name = '',
                namespace = pulpcore.client.pulp_ansible.models.collection_namespace_response.CollectionNamespaceResponse(
                    name = '', 
                    metadata_sha256 = '', ),
                signatures = [
                    pulpcore.client.pulp_ansible.models.collection_version_signature_response.CollectionVersionSignatureResponse(
                        signature = '', 
                        pubkey_fingerprint = '', 
                        signing_service = '', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                metadata = pulpcore.client.pulp_ansible.models.collection_metadata_response.CollectionMetadataResponse(
                    authors = [
                        ''
                        ], 
                    contents = null, 
                    dependencies = null, 
                    description = '', 
                    documentation = '', 
                    homepage = '', 
                    issues = '', 
                    license = [
                        ''
                        ], 
                    repository = '', 
                    tags = [
                        ''
                        ], ),
                git_url = '',
                git_commit_sha = ''
            )
        else:
            return UnpaginatedCollectionVersionResponse(
                version = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                signatures = [
                    pulpcore.client.pulp_ansible.models.collection_version_signature_response.CollectionVersionSignatureResponse(
                        signature = '', 
                        pubkey_fingerprint = '', 
                        signing_service = '', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
        )
        """

    def testUnpaginatedCollectionVersionResponse(self):
        """Test UnpaginatedCollectionVersionResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from pulpcore.client.pulp_ansible.models.ansible_tag_response import AnsibleTagResponse
from typing import Optional, Set
from typing_extensions import Self


class OneOf:
    @staticmethod
    def from_dict(obj, *args, **kwargs):
        """Noop override to fix missing OneOf import/implementation."""
        return obj


class AnsibleCollectionVersionResponse(BaseModel):
    """
    A serializer for CollectionVersion Content.
    """ # noqa: E501
    prn: Optional[StrictStr] = Field(default=None, description="The Pulp Resource Name (PRN).")
    pulp_labels: Optional[Dict[str, Optional[StrictStr]]] = Field(default=None, description="A dictionary of arbitrary key/value pairs used to describe a specific Content instance.")
    artifact: Optional[StrictStr] = Field(default=None, description="Artifact file representing the physical content")
    pulp_created: Optional[datetime] = Field(default=None, description="Timestamp of creation.")
    pulp_last_updated: Optional[datetime] = Field(default=None, description="Timestamp of the last time this resource was updated. Note: for immutable resources - like content, repository versions, and publication - pulp_created and pulp_last_updated dates will be the same.")
    pulp_href: Optional[StrictStr] = None
    sha256: Optional[StrictStr] = Field(default=None, description="The SHA-256 checksum if available.")
    md5: Optional[StrictStr] = Field(default=None, description="The MD5 checksum if available.")
    sha1: Optional[StrictStr] = Field(default=None, description="The SHA-1 checksum if available.")
    sha224: Optional[StrictStr] = Field(default=None, description="The SHA-224 checksum if available.")
    sha384: Optional[StrictStr] = Field(default=None, description="The SHA-384 checksum if available.")
    sha512: Optional[StrictStr] = Field(default=None, description="The SHA-512 checksum if available.")
    id: Optional[StrictStr] = Field(default=None, description="A collection identifier.")
    authors: Optional[List[Annotated[str, Field(strict=True, max_length=64)]]] = Field(default=None, description="A list of the CollectionVersion content's authors.")
    dependencies: Optional[Dict[str, Any]] = Field(default=None, description="A dict declaring Collections that this collection requires to be installed for it to be usable.")
    description: Optional[StrictStr] = Field(default=None, description="A short summary description of the collection.")
    documentation: Optional[Annotated[str, Field(strict=True, max_length=2000)]] = Field(default=None, description="The URL to any online docs.")
    homepage: Optional[Annotated[str, Field(strict=True, max_length=2000)]] = Field(default=None, description="The URL to the homepage of the collection/project.")
    issues: Optional[Annotated[str, Field(strict=True, max_length=2000)]] = Field(default=None, description="The URL to the collection issue tracker.")
    license: Optional[List[Annotated[str, Field(strict=True, max_length=32)]]] = Field(default=None, description="A list of licenses for content inside of a collection.")
    name: Optional[Annotated[str, Field(strict=True, max_length=64)]] = Field(default=None, description="The name of the collection.")
    namespace: Optional[Annotated[str, Field(strict=True, max_length=64)]] = Field(default=None, description="The namespace of the collection.")
    origin_repository: Optional[Annotated[str, Field(strict=True, max_length=2000)]] = Field(default=None, description="The URL of the originating SCM repository.")
    tags: Optional[List[AnsibleTagResponse]] = None
    version: Optional[Annotated[str, Field(strict=True, max_length=128)]] = Field(default=None, description="The version of the collection.")
    requires_ansible: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="The version of Ansible required to use the collection. Multiple versions can be separated with a comma.")
    __properties: ClassVar[List[str]] = ["prn", "pulp_labels", "artifact", "pulp_created", "pulp_last_updated", "pulp_href", "sha256", "md5", "sha1", "sha224", "sha384", "sha512", "id", "authors", "dependencies", "description", "documentation", "homepage", "issues", "license", "name", "namespace", "origin_repository", "tags", "version", "requires_ansible"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AnsibleCollectionVersionResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "prn",
            "pulp_created",
            "pulp_last_updated",
            "pulp_href",
            "sha256",
            "md5",
            "sha1",
            "sha224",
            "sha384",
            "sha512",
            "id",
            "authors",
            "dependencies",
            "description",
            "documentation",
            "homepage",
            "issues",
            "license",
            "name",
            "namespace",
            "origin_repository",
            "tags",
            "version",
            "requires_ansible",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in tags (list)
        _items = []
        if self.tags:
            for _item_tags in self.tags:
                if _item_tags:
                    _items.append(_item_tags.to_dict())
            _dict['tags'] = _items
        # set to None if requires_ansible (nullable) is None
        # and model_fields_set contains the field
        if self.requires_ansible is None and "requires_ansible" in self.model_fields_set:
            _dict['requires_ansible'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AnsibleCollectionVersionResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "prn": obj.get("prn"),
            "pulp_labels": obj.get("pulp_labels"),
            "artifact": obj.get("artifact"),
            "pulp_created": obj.get("pulp_created"),
            "pulp_last_updated": obj.get("pulp_last_updated"),
            "pulp_href": obj.get("pulp_href"),
            "sha256": obj.get("sha256"),
            "md5": obj.get("md5"),
            "sha1": obj.get("sha1"),
            "sha224": obj.get("sha224"),
            "sha384": obj.get("sha384"),
            "sha512": obj.get("sha512"),
            "id": obj.get("id"),
            "authors": obj.get("authors"),
            "dependencies": obj.get("dependencies"),
            "description": obj.get("description"),
            "documentation": obj.get("documentation"),
            "homepage": obj.get("homepage"),
            "issues": obj.get("issues"),
            "license": obj.get("license"),
            "name": obj.get("name"),
            "namespace": obj.get("namespace"),
            "origin_repository": obj.get("origin_repository"),
            "tags": [AnsibleTagResponse.from_dict(_item) for _item in obj["tags"]] if obj.get("tags") is not None else None,
            "version": obj.get("version"),
            "requires_ansible": obj.get("requires_ansible")
        })
        return _obj





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self


class OneOf:
    @staticmethod
    def from_dict(obj, *args, **kwargs):
        """Noop override to fix missing OneOf import/implementation."""
        return obj


class CollectionMetadataResponse(BaseModel):
    """
    A serializer for a CollectionVersion metadata.
    """ # noqa: E501
    authors: Optional[List[Annotated[str, Field(strict=True, max_length=64)]]] = None
    contents: Optional[Any] = None
    dependencies: Optional[Any] = None
    description: Optional[StrictStr] = None
    documentation: Optional[StrictStr] = None
    homepage: Optional[StrictStr] = None
    issues: Optional[StrictStr] = None
    license: Optional[List[Annotated[str, Field(strict=True, max_length=32)]]] = None
    repository: Optional[StrictStr] = None
    tags: List[StrictStr]
    __properties: ClassVar[List[str]] = ["authors", "contents", "dependencies", "description", "documentation", "homepage", "issues", "license", "repository", "tags"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CollectionMetadataResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "authors",
            "contents",
            "dependencies",
            "description",
            "documentation",
            "homepage",
            "issues",
            "license",
            "repository",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if contents (nullable) is None
        # and model_fields_set contains the field
        if self.contents is None and "contents" in self.model_fields_set:
            _dict['contents'] = None

        # set to None if dependencies (nullable) is None
        # and model_fields_set contains the field
        if self.dependencies is None and "dependencies" in self.model_fields_set:
            _dict['dependencies'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CollectionMetadataResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "authors": obj.get("authors"),
            "contents": obj.get("contents"),
            "dependencies": obj.get("dependencies"),
            "description": obj.get("description"),
            "documentation": obj.get("documentation"),
            "homepage": obj.get("homepage"),
            "issues": obj.get("issues"),
            "license": obj.get("license"),
            "repository": obj.get("repository"),
            "tags": obj.get("tags")
        })
        return _obj


